Learn R Programming

inldata (version 1.2.7)

counties: County Boundaries

Description

County boundaries in the vicinity of Idaho National Laboratory, eastern Idaho.

Usage

counties

Arguments

Format

A simple feature with fields:

name

County name.

id

Unique identifier.

geometry

Polygon geometry with a positive area (two-dimensional); sequence of points that form a closed, non-self-intersecting ring; the first ring denotes the exterior ring, zero or more subsequent rings denote holes in this exterior ring.

Examples

Run this code
print(counties)

Run the code above in your browser using DataLab