Learn R Programming

inldata (version 1.2.7)

lakes: Lakes and Ponds

Description

Perennial lakes and ponds in the vicinity of the Idaho National Laboratory (INL) in eastern Idaho.

Usage

lakes

Arguments

Format

A simple feature with fields:

gnis_nm

GNIS name.

id

Unique identifier.

reach_cd

Reach code, a unique 14-digit code that identifies a continuous piece of surface water with similar hydrologic characteristics.

gnis_id

Geographic Names Information System (GNIS) identifier.

feature_tp

USGS National Hydrography Dataset (NHD) feature type code. "LakePond" is a standing body of water with a predominantly natural shoreline surrounded by land; "Reservoir" is a constructed basin formed to contain water or other liquids; and "SwampMarsh" is a non-cultivated, vegetated area that is inundated or saturated for a significant part of the year.

geometry

Polygon geometry with a positive area (two-dimensional); sequence of points that form a closed, non-self-intersecting ring; the first ring denotes the exterior ring, zero or more subsequent rings denote holes in this exterior ring.

Examples

Run this code
print(lakes)

Run the code above in your browser using DataLab